==> yak-demo-common-app-3.1.0-sources.jar: org/crazyyak/demo/common/app/domain/AccountStore.java <==
package org.crazyyak.demo.common.app.domain;

import java.util.List;
import org.crazyyak.demo.common.app.DemoCouchServer;
import org.crazyyak.dev.couchace.DefaultCouchStore;
import org.springframework.beans.factory.annotation.*;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Component;

@Component
public class AccountStore extends DefaultCouchStore<Account> {

  public static final String ACCOUNT_DESIGN_NAME = "account";

  @Autowired
  public AccountStore(DemoCouchServer couchServer, @Value("${couchdb.name}") String databaseName) {
    super(couchServer, databaseName, Account.class);
  }

  @Override
  public String getDesignName() {
    return ACCOUNT_DESIGN_NAME;
  }

  public List<Account> getAll() {
    return super.getEntities("allAccounts");
  }

  public Account getByEmailAddress(String emailAddress) {
    if (emailAddress == null) return null;
    List<Account> response = super.getEntities("byEmailAddress", emailAddress);
    return response.isEmpty() ? null : response.get(0);
  }

  public Account get(CurrentUser currentUser) {
    if (currentUser == null) return null;
    String documentId = currentUser.getAccountId();
    return super.getByDocumentId(documentId);
  }

  public CurrentUser getCurrentUser() {
    Authentication auth = SecurityContextHolder.getContext().getAuthentication();

    if (auth != null) {
      Object principal = auth.getPrincipal();
      if (principal instanceof CurrentUser) {
        return (CurrentUser)principal;
      }
    }

    return null;
  }

  public Account getCurrentAccount() {
    CurrentUser currentUser = getCurrentUser();
    return get(currentUser);
  }
}

==> yak-demo-common-app-3.2.1-sources.jar: org/crazyyak/demo/common/app/domain/AccountStore.java <==
package org.crazyyak.demo.common.app.domain;

import java.util.List;
import org.crazyyak.demo.common.app.DemoCouchServer;
import org.crazyyak.dev.couchace.DefaultCouchStore;
import org.crazyyak.dev.security.domain.*;
import org.springframework.beans.factory.annotation.*;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Component;

@Component
public class AccountStore extends DefaultCouchStore<Account> implements CurrentUserStore {

  public static final String ACCOUNT_DESIGN_NAME = "account";

  @Autowired
  public AccountStore(DemoCouchServer couchServer, @Value("${couchdb.name}") String databaseName) {
    super(couchServer, databaseName, Account.class);
  }

  @Override
  public String getDesignName() {
    return ACCOUNT_DESIGN_NAME;
  }

  public List<Account> getAll() {
    return super.getEntities("allAccounts");
  }

  public Account getByEmailAddress(String emailAddress) {
    if (emailAddress == null) return null;
    List<Account> response = super.getEntities("byEmailAddress", emailAddress);
    return response.isEmpty() ? null : response.get(0);
  }

  public Account get(CurrentUser currentUser) {
    if (currentUser == null) return null;
    String documentId = currentUser.getAccountId();
    return super.getByDocumentId(documentId);
  }

  public CurrentUser getCurrentUser() {
    Authentication auth = SecurityContextHolder.getContext().getAuthentication();

    if (auth != null) {
      Object principal = auth.getPrincipal();
      if (principal instanceof CurrentUser) {
        return (CurrentUser)principal;
      }
    }

    return null;
  }

  public Account getCurrentAccount() {
    CurrentUser currentUser = getCurrentUser();
    return get(currentUser);
  }

  @Override
  public CurrentUserSource getCurrentUserSourceByName(String username) {
    // for this app, the user name and email address are one in the same.
    return getByEmailAddress(username);
  }

  @Override
  public CurrentUserSource getCurrentUserSourceByEmail(String email) {
    return getByEmailAddress(email);
  }
}
